# @datafire/azure_sql_manageddatabasevulnerabilityassessments

Client library for SqlManagementClient

## Installation and Usage
```bash
npm install --save @datafire/azure_sql_manageddatabasevulnerabilityassessments
```
```js
let azure_sql_manageddatabasevulnerabilityassessments = require('@datafire/azure_sql_manageddatabasevulnerabilityassessments').create({
  access_token: "",
  refresh_token: "",
  client_id: "",
  client_secret: "",
  redirect_uri: ""
});

.then(data => {
  console.log(data);
});
```

## Description

The Azure SQL Database management API provides a RESTful set of web APIs that interact with Azure SQL Database services to manage your databases. The API enables users to create, retrieve, update, and delete databases, servers, and other entities.

## Actions

### ManagedDatabaseVulnerabilityAssessments_ListByDatabase
Lists the vulnerability assessments of a managed database.


```js
azure_sql_manageddatabasevulnerabilityassessments.ManagedDatabaseVulnerabilityAssessments_ListByDatabase({
  "resourceGroupName": "",
  "managedInstanceName": "",
  "databaseName": "",
  "subscriptionId": "",
  "api-version": ""
}, context)
```

#### Input
* input `object`
  * resourceGroupName **required** `string`: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
  * managedInstanceName **required** `string`: The name of the managed instance.
  * databaseName **required** `string`: The name of the database for which the vulnerability assessment is defined.
  * subscriptionId **required** `string`: The subscription ID that identifies an Azure subscription.
  * api-version **required** `string`: The API version to use for the request.

#### Output
* output [DatabaseVulnerabilityAssessmentListResult](#databasevulnerabilityassessmentlistresult)

### ManagedDatabaseVulnerabilityAssessments_Delete
Removes the database's vulnerability assessment.


```js
azure_sql_manageddatabasevulnerabilityassessments.ManagedDatabaseVulnerabilityAssessments_Delete({
  "resourceGroupName": "",
  "managedInstanceName": "",
  "databaseName": "",
  "vulnerabilityAssessmentName": "",
  "subscriptionId": "",
  "api-version": ""
}, context)
```

#### Input
* input `object`
  * resourceGroupName **required** `string`: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
  * managedInstanceName **required** `string`: The name of the managed instance.
  * databaseName **required** `string`: The name of the database for which the vulnerability assessment is defined.
  * vulnerabilityAssessmentName **required** `string` (values: default): The name of the vulnerability assessment.
  * subscriptionId **required** `string`: The subscription ID that identifies an Azure subscription.
  * api-version **required** `string`: The API version to use for the request.

#### Output
*Output schema unknown*

### ManagedDatabaseVulnerabilityAssessments_Get
Gets the database's vulnerability assessment.


```js
azure_sql_manageddatabasevulnerabilityassessments.ManagedDatabaseVulnerabilityAssessments_Get({
  "resourceGroupName": "",
  "managedInstanceName": "",
  "databaseName": "",
  "vulnerabilityAssessmentName": "",
  "subscriptionId": "",
  "api-version": ""
}, context)
```

#### Input
* input `object`
  * resourceGroupName **required** `string`: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
  * managedInstanceName **required** `string`: The name of the managed instance.
  * databaseName **required** `string`: The name of the database for which the vulnerability assessment is defined.
  * vulnerabilityAssessmentName **required** `string` (values: default): The name of the vulnerability assessment.
  * subscriptionId **required** `string`: The subscription ID that identifies an Azure subscription.
  * api-version **required** `string`: The API version to use for the request.

#### Output
* output [DatabaseVulnerabilityAssessment](#databasevulnerabilityassessment)

### ManagedDatabaseVulnerabilityAssessments_CreateOrUpdate
Creates or updates the database's vulnerability assessment.


```js
azure_sql_manageddatabasevulnerabilityassessments.ManagedDatabaseVulnerabilityAssessments_CreateOrUpdate({
  "resourceGroupName": "",
  "managedInstanceName": "",
  "databaseName": "",
  "vulnerabilityAssessmentName": "",
  "parameters": {},
  "subscriptionId": "",
  "api-version": ""
}, context)
```

#### Input
* input `object`
  * resourceGroupName **required** `string`: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
  * managedInstanceName **required** `string`: The name of the managed instance.
  * databaseName **required** `string`: The name of the database for which the vulnerability assessment is defined.
  * vulnerabilityAssessmentName **required** `string` (values: default): The name of the vulnerability assessment.
  * parameters **required** [DatabaseVulnerabilityAssessment](#databasevulnerabilityassessment)
  * subscriptionId **required** `string`: The subscription ID that identifies an Azure subscription.
  * api-version **required** `string`: The API version to use for the request.

#### Output
* output [DatabaseVulnerabilityAssessment](#databasevulnerabilityassessment)



## Definitions

### DatabaseVulnerabilityAssessment
* DatabaseVulnerabilityAssessment `object`: A database vulnerability assessment.
  * properties [DatabaseVulnerabilityAssessmentProperties](#databasevulnerabilityassessmentproperties)
  * id `string`: Resource ID.
  * name `string`: Resource name.
  * type `string`: Resource type.

### DatabaseVulnerabilityAssessmentListResult
* DatabaseVulnerabilityAssessmentListResult `object`: A list of the database's vulnerability assessments.
  * nextLink `string`: Link to retrieve next page of results.
  * value `array`: Array of results.
    * items [DatabaseVulnerabilityAssessment](#databasevulnerabilityassessment)

### DatabaseVulnerabilityAssessmentProperties
* DatabaseVulnerabilityAssessmentProperties `object`: Properties of a database Vulnerability Assessment.
  * recurringScans [VulnerabilityAssessmentRecurringScansProperties](#vulnerabilityassessmentrecurringscansproperties)
  * storageAccountAccessKey `string`: Specifies the identifier key of the storage account for vulnerability assessment scan results. If 'StorageContainerSasKey' isn't specified, storageAccountAccessKey is required.
  * storageContainerPath `string`: A blob storage container path to hold the scan results (e.g. https://myStorage.blob.core.windows.net/VaScans/).  It is required if server level vulnerability assessment policy doesn't set
  * storageContainerSasKey `string`: A shared access signature (SAS Key) that has read and write access to the blob container specified in 'storageContainerPath' parameter. If 'storageAccountAccessKey' isn't specified, StorageContainerSasKey is required.

### VulnerabilityAssessmentRecurringScansProperties
* VulnerabilityAssessmentRecurringScansProperties `object`: Properties of a Vulnerability Assessment recurring scans.
  * emailSubscriptionAdmins `boolean`: Specifies that the schedule scan notification will be is sent to the subscription administrators.
  * emails `array`: Specifies an array of e-mail addresses to which the scan notification is sent.
    * items `string`
  * isEnabled `boolean`: Recurring scans state.


